@@ -5,11 +5,15 @@ t.drop();
 
 // Utility function to list plans for a query.
 function getPlans(query, sort, projection) {
-    var key = {query: query, sort: sort, projection: projection};
+    var key = {
+        query: query,
+        sort: sort,
+        projection: projection
+    };
     var res = t.runCommand('planCacheListPlans', key);
     assert.commandWorked(res, 'planCacheListPlans(' + tojson(key, '', true) + ' failed');
-    assert(res.hasOwnProperty('plans'), 'plans missing from planCacheListPlans(' +
-           tojson(key, '', true) + ') result');
+    assert(res.hasOwnProperty('plans'),
+           'plans missing from planCacheListPlans(' + tojson(key, '', true) + ') result');
     return res.plans;
 }
 
@@ -20,14 +24,16 @@ t.save({a: 2, b: 2});
 
 // We need two indices so that the MultiPlanRunner is executed.
 t.ensureIndex({a: 1});
-t.ensureIndex({a: 1, b:1});
+t.ensureIndex({a: 1, b: 1});
 
 // Invalid key should be an error.
-assert.eq(0, getPlans({unknownfield: 1}, {}, {}),
+assert.eq(0,
+          getPlans({unknownfield: 1}, {}, {}),
           'planCacheListPlans should return empty results on unknown query shape');
 
 // Create a cache entry.
-assert.eq(1, t.find({a: 1, b: 1}, {_id: 0, a: 1}).sort({a: -1}).itcount(),
+assert.eq(1,
+          t.find({a: 1, b: 1}, {_id: 0, a: 1}).sort({a: -1}).itcount(),
           'unexpected document count');
 
 // Retrieve plans for valid cache entry.
@@ -65,10 +71,10 @@ for (var i = 0; i < plans.length; i++) {
     print('plan ' + i + ': ' + tojson(plans[i]));
     assert.gt(plans[i].reason.score, 0, 'plan ' + i + ' score is invalid');
     if (i > 0) {
-        assert.lte(plans[i].reason.score, plans[i-1].reason.score,
+        assert.lte(plans[i].reason.score,
+                   plans[i - 1].reason.score,
                    'plans not sorted by score in descending order. ' +
-                   'plan ' + i + ' has a score that is greater than that of the previous plan');
+                       'plan ' + i + ' has a score that is greater than that of the previous plan');
     }
     assert(plans[i].reason.stats.hasOwnProperty('stage'), 'no stats inserted for plan ' + i);
 }
-
